@@ -1,5 +1,5 @@
 /*
- * $Id: mime_parser.c 6304 2008-05-21 17:24:41Z ajc $
+ * $Id: mime_parser.c 6555 2008-08-31 20:09:39Z dothebart $
  *
  * This is the MIME parser for Citadel.
  *
@@ -678,7 +678,7 @@ MimeGuess MyMimes [] = {
 };
 
 
-const char *GuessMimeType(char *data, size_t dlen)
+const char *GuessMimeType(const char *data, size_t dlen)
 {
 	int MimeIndex = 0;
 
@@ -752,6 +752,7 @@ static void DeleteIcon(void *IconNamePtr)
 	IconName *Icon = (IconName*) IconNamePtr;
 	free(Icon->FlatName);
 	free(Icon->FileName);
+	free(Icon);
 }
 
 /*
@@ -837,6 +838,7 @@ int LoadIconDir(const char *DirName)
 		Put(IconHash, Icon->FlatName, d_without_ext, Icon, DeleteIcon);
 //		PrintHash(IconHash, PrintFlat, PrintFile);
 	}
+	closedir(filedir);
 	return 1;
 }
 
